@@ -1194,7 +1194,7 @@ DBFGetFieldInfo(DBFHandle psDBF, int iField, char *pszFieldName,
 /************************************************************************/
 
 static int
-DBFWriteAttribute(DBFHandle psDBF, int hEntity, int iField, void *pValue)
+DBFWriteAttribute(DBFHandle psDBF, int hEntity, int iField, const void *pValue)
 {
     int nRecordOffset, i, j, nRetResult = TRUE;
     unsigned char *pabyRec;
@@ -1337,7 +1337,7 @@ DBFWriteAttribute(DBFHandle psDBF, int hEntity, int iField, void *pValue)
 		nWidth = sizeof(szSField) - 2;
 
 	    sprintf(szFormat, "%%%dd", nWidth);
-	    sprintf(szSField, szFormat, (int) *((double *) pValue));
+	    sprintf(szSField, szFormat, (int) *((const double *) pValue));
 	    if ((int) strlen(szSField) > psDBF->panFieldSize[iField]) {
 		szSField[psDBF->panFieldSize[iField]] = '\0';
 		nRetResult = FALSE;
@@ -1355,7 +1355,7 @@ DBFWriteAttribute(DBFHandle psDBF, int hEntity, int iField, void *pValue)
 
 	    sprintf(szFormat, "%%%d.%df",
 		    nWidth, psDBF->panFieldDecimals[iField]);
-	    sprintf(szSField, szFormat, *((double *) pValue));
+	    sprintf(szSField, szFormat, *((const double *) pValue));
 	    if ((int) strlen(szSField) > psDBF->panFieldSize[iField]) {
 		szSField[psDBF->panFieldSize[iField]] = '\0';
 		nRetResult = FALSE;
@@ -1367,22 +1367,22 @@ DBFWriteAttribute(DBFHandle psDBF, int hEntity, int iField, void *pValue)
 
     case 'L':
 	if (psDBF->panFieldSize[iField] >= 1 &&
-	    (*(char *) pValue == 'F' || *(char *) pValue == 'T'))
-	    *(pabyRec + psDBF->panFieldOffset[iField]) = *(char *) pValue;
+	    (*(const char *) pValue == 'F' || *(const char *) pValue == 'T'))
+	    *(pabyRec + psDBF->panFieldOffset[iField]) = *(const char *) pValue;
 	break;
 
     default:
-	if ((int) strlen((char *) pValue) > psDBF->panFieldSize[iField]) {
+	if ((int) strlen((const char *) pValue) > psDBF->panFieldSize[iField]) {
 	    j = psDBF->panFieldSize[iField];
 	    nRetResult = FALSE;
 	} else {
 	    memset(pabyRec + psDBF->panFieldOffset[iField], ' ',
 		   psDBF->panFieldSize[iField]);
-	    j = strlen((char *) pValue);
+	    j = strlen((const char *) pValue);
 	}
 
 	strncpy((char *) (pabyRec + psDBF->panFieldOffset[iField]),
-		(char *) pValue, j);
+		(const char *) pValue, j);
 	break;
     }
 
